# Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# This function takes up to two arguments:
#         1. error message
#         2. exit code (default: 1)
#
# Example: test -n "$VAR" || die "VAR is not set!" 5
# If variable $VAR is not set, "VAR is not set!" will be printed on stderr
# and script in which it was invoked will exit with exit code equal to 5.
#
# Author: Aleksander Mistewicz <a.mistewicz@samsung.com>

die() {
    printf >&2 -- '%s\n' "$1"
    exit "${2:-1}"
}

# INIT_SLEEP <= RESTART_SLEEP <= MAX_SLEEP
INC_SLEEP=10
INIT_SLEEP=60
RESTART_SLEEP=80
MAX_SLEEP=140

TL_IP_CONF="/etc/opt/testlab-major/ip_addr"
SCREENSHOOTER_RPM="/opt/screenshooter.rpm"
ARTIK_FLASH_SCRIPT="/opt/sdboot/mk_sdboot.sh"
ARTIK_RESTART_SLEEP="5000"

BMAP_TIME_LIMIT="600"

get_ip() {
    SDMUX="$1"
    test -n "${SDMUX}" || die "Missing argument: sdmux!"

    test -f "${TL_IP_CONF}" ||
        die "Required conf file does not exist or is not accessible: ${TL_IP_CONF}"
    IP="$(awk -v SDMUX="${SDMUX}" '$2 == SDMUX {print $1}' "${TL_IP_CONF}")"
    test -n "${IP}" || die "Missing entry in: ${TL_IP_CONF}"
    echo "${IP}"
}
